ActionButton<T> class

Inheritance

Constructors

ActionButton({Key? key, required ValueGetter<FutureOr<T>> onAction, ValueChanged<T>? onActionResult, bool autofocus = false, ObservableData<bool>? enabled, ActionButtonBuilder buttonBuilder = buttonText, Object? label, Widget? child, WidgetBuilder? builder})
ActionButton.negative({Key? key, required ValueGetter<FutureOr<T>> onAction, ValueChanged<T>? onActionResult, bool autofocus = false, ObservableData<bool>? enabled, ActionButtonBuilder buttonBuilder = buttonText})
const
ActionButton.neutral({Key? key, required ValueGetter<FutureOr<T>> onAction, ValueChanged<T>? onActionResult, bool autofocus = false, ObservableData<bool>? enabled, ActionButtonBuilder buttonBuilder = buttonText})
const
ActionButton.positive({Key? key, required ValueGetter<FutureOr<T>> onAction, ValueChanged<T>? onActionResult, bool autofocus = false, ObservableData<bool>? enabled, ActionButtonBuilder buttonBuilder = buttonText})
const

Properties

autofocus → bool
final
buttonBuilder → ActionButtonBuilder
final
contentBuilder → WidgetBuilder
final
enabled → ObservableData<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAction → ValueGetter<FutureOr<T>>
final
onActionResult → ValueChanged<T>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

buttonElevated({required VoidCallback? onPressed, required bool autofocus, required Widget child}) → Widget
buttonFilled({required VoidCallback? onPressed, required bool autofocus, required Widget child}) → Widget
buttonOutlined({required VoidCallback? onPressed, required bool autofocus, required Widget child}) → Widget
buttonText({required VoidCallback? onPressed, required bool autofocus, required Widget child}) → Widget
negativeText(BuildContext context) → Widget
neutralText(BuildContext context) → Widget
positiveText(BuildContext context) → Widget