Message class

Annotations

Constructors

Message({required IconData icon, required Color color, required String title, String? body, Future? cancel, List<MessageAction>? actions})
const
Message.error({required String title, String? body, Future? cancel, List<MessageAction>? actions})
const
Message.info({required String title, String? body, Future? cancel, List<MessageAction>? actions})
const
Message.success({required String title, String? body, Future? cancel, List<MessageAction>? actions})
const
Message.warning({required String title, String? body, Future? cancel, List<MessageAction>? actions})
const

Properties

actions → List<MessageAction>?
final
body → String?
final
cancel → Future?
final
color → Color
final
hashCode → int
The hash code for this object.
no setteroverride
icon → IconData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

build(BuildContext context, {VoidCallback? onClose, VoidCallback? onCancel}) → MaterialBanner
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context, {bool dismissCurrent = true}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override