TaskViewModel mixin

Superclass constraints

Properties

activeTasks → LiveMap<String?, Set<TaskInfo>>
final
context → BuildContext
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
loading → LiveData<bool>
no setter
provider → ViewModelProvider
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleTaskError(TaskInfo task, Object error, StackTrace stackTrace) → void
handleTaskSuccess(TaskInfo task) → void
loadingDependsOn(TaskViewModel other, {String? childTag, String? tag}) → void
loadingWithTag(String tag) → LiveData<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyTask<T>(Future<T> task, {String tag = 'main', JsonObject args = const {}}) → Future<T>
onCleared() → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited