NiceDialog<T> class

Inheritance

Constructors

NiceDialog({Key? key, Widget? title, EdgeInsetsGeometry titlePadding = const EdgeInsets.only(left: m24, top: m12, right: m24, bottom: m8), ShapeBorder shape = const RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(8))), EdgeInsetsGeometry actionsPadding = const EdgeInsets.symmetric(horizontal: m16, vertical: m8), ObservableData<bool>? actionsEnabled, bool actionClose = false, bool actionCancel = true, bool actionSubmit = true, bool actionSubmitAutofocus = true, bool contentExpanded = false, bool contentScrollable = false, BoxConstraints contentConstraints = kIsWeb ? const BoxConstraints(minWidth: 420, maxWidth: 552, minHeight: 24, maxHeight: 420) : const BoxConstraints(minWidth: 320, maxWidth: 420, minHeight: 24, maxHeight: 280), EdgeInsetsGeometry contentPadding = const EdgeInsets.only(left: m24, right: m24, bottom: m8), required Widget content, ValueGetter<FutureOr<bool>> submitForm = _defaultSubmitForm, ValueGetter<T>? submitResult})
const

Properties

actionCancel → bool
final
actionClose → bool
final
actionsEnabled → ObservableData<bool>?
final
actionsPadding → EdgeInsetsGeometry
final
actionSubmit → bool
final
actionSubmitAutofocus → bool
final
content → Widget
final
contentConstraints → BoxConstraints
final
contentExpanded → bool
final
contentPadding → EdgeInsetsGeometry
final
contentScrollable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder
final
submitForm → ValueGetter<FutureOr<bool>>
final
submitResult → ValueGetter<T>?
final
title → Widget?
final
titlePadding → EdgeInsetsGeometry
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited