ScrollContextState<T extends StatefulWidget> class abstract

Inheritance
Implemented types
Mixed-in types
Implementers

Constructors

ScrollContextState()

Properties

axisDirection → AxisDirection
The direction in which the widget scrolls.
no setterinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
devicePixelRatio → double
The FlutterView.devicePixelRatio of the view that the Scrollable this ScrollContext is associated with is drawn into.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
notificationContext → BuildContext?
The BuildContext that should be used when dispatching ScrollNotifications.
no setteroverride
position ↔ ScrollPosition
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageContext → BuildContext
The BuildContext that should be used when searching for a PageStorage.
no setteroverride
vsync → TickerProvider
A TickerProvider to use when animating the scroll position.
no setteroverride
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
disposeScrollPosition(ScrollController controller) → void
initScrollPosition(ScrollController controller, ScrollPhysics physics) → void
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
saveOffset(double offset) → void
Called by the ScrollPosition whenever scrolling ends to persist the provided scroll offset for state restoration purposes.
override
setCanDrag(bool value) → void
Whether the user can drag the widget, for example to initiate a scroll.
override
setIgnorePointer(bool value) → void
Whether the contents of the widget should ignore PointerEvent inputs.
override
setSemanticsActions(Set<SemanticsAction> actions) → void
Set the SemanticsActions that should be expose to the semantics tree.
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateScrollPosition(ScrollController controller) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited